class search_algo:
    """
    This Class is for Linear Search and Binary Search Algorithms.
    """
    def linearSearch(self,arr,target):
        """
        
        This is Linear Search Algorithm , which works in O(n).
        This Function RETURN THE INDEX OF THE TARGET.
        
        """
        for i in range(len(arr)):
            if arr[i] == target:
                return i
        return "NO SUCH VALUE IN THE LIST."
    
    def binarySearch(self,arr,target):
        l = 0
        r = len(arr)-1
        mid = (l+r)//2
        for i in range(len(arr)):
            if arr[i] == target:
                return i
            else:
                if target<arr[mid]:
                    l = mid
                else:
                    r = mid

        return "NO SUCH VALUE IN THE LIST."


from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = 'This package includes algorithms such as LinearSearch,BinarySearch, Two pointer , Sliding window. It will get updated every week!!!'

# Setting up
setup(
    name="search_sort_array_algo",
    version=VERSION,
    author="Rumour(Sarthak Samantaray)",
    author_email="<sarthak.samantaraycoding@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    keywords=['python', 'Algorithms', 'Arrays', 'Strings', 'Linked List', 'Stacks'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)